"""
Tests for Vela
"""
import argparse
from unittest.mock import patch, MagicMock

import vela.quasar as quasar

expected_settings = {
    "useCasa": False,
    "homeForReprocessing": "/home/casa/packages/pipeline/current",
    "rootDirectory": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool",
    "processingDirectory": "tmpabcd1234",
}
args = argparse.Namespace()


class TestQuasar:
    def test_get_settings(self):
        with patch(
            "pathlib.Path.cwd",
            MagicMock(
                return_value="/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmpabcd1234"
            ),
        ) as cwd:
            settings = quasar._get_settings(cwd)
            assert settings["useCasa"] == expected_settings["useCasa"]
            assert settings["homeForReprocessing"] == expected_settings["homeForReprocessing"]

    @patch("os.chdir")
    @patch("pathlib.Path")
    @patch("os.getcwd")
    def test_main_stdcal(self, mock_cwd, mock_path, mock_chdir):
        args.standard_cal = ["test/test.json", "test/PPR.xml"]

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)) as mock_args:
            with patch("vela.emulators.CalibrationEmulator.run") as run:
                quasar.main()
                assert run.call_count == 1

        # reset for testing
        args.standard_cal = None

    @patch("os.chdir")
    @patch("pathlib.Path")
    @patch("os.getcwd")
    def test_main_stdimg(self, mock_cwd, mock_path, mock_chdir):
        args.standard_img = ["test/image-metadata.json", "test/cmsimage-PPR.xml"]

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)) as mock_args:
            with patch("vela.emulators.ImagingEmulator.run") as run:
                quasar.main()
                assert run.call_count == 1

        # reset for testing
        args.standard_img = None
