from pyramid.config import Configurator


def includeme(config: Configurator):
    """
    Function that gets included in server.py:main(); calls all route adding functions

    :param config: Pyramid server config object
    """
    default_routes(config)
    capability_routes(config)
    capability_request_routes(config)
    capability_version_routes(config)


def default_routes(config: Configurator):
    """
    Uncategorized server routes

    :param config: Pyramid server config object
    """
    config.add_route("home", "/")


def capability_routes(config: Configurator):
    """
    Server routes related to capabilities

    :param config: Pyramid server config object
    """
    capability_url = "capability/{capability_name}"
    # GET
    config.add_route(name="view_capability", pattern=f"{capability_url}", request_method="GET")
    config.add_route(name="view_active_capability_requests", pattern=f"{capability_url}/request")
    config.add_route(
        name="view_created_capability_requests", pattern=f"{capability_url}/created-requests"
    )
    # POST
    config.add_route(
        name="create_capability",
        pattern="capability/create",
        request_method="POST",
    )
    config.add_route(
        name="edit_capability",
        pattern=f"{capability_url}",
        request_method="POST",
    )
    config.add_route(
        name="enable_capability", pattern=f"{capability_url}/enable", request_method="POST"
    )
    config.add_route(
        name="disable_capability", pattern=f"{capability_url}/disable", request_method="POST"
    )


def capability_request_routes(config: Configurator):
    """
    Server routes related to capability requests

    :param config: Pyramid server config object
    """
    request_url = "capability/request/{request_id}"
    # GET
    config.add_route(name="view_capability_request", pattern=f"{request_url}", request_method="GET")
    # POST
    config.add_route(
        name="create_capability_request",
        pattern="capability/{capability_name}/request/create",
        request_method="POST",
    )
    config.add_route(
        name="edit_capability_request",
        pattern=f"{request_url}",
        request_method="POST",
    )
    config.add_route(
        name="submit_capability_request", pattern=f"{request_url}/submit", request_method="POST"
    )
    config.add_route(
        name="cancel_capability_request", pattern=f"{request_url}/cancel", request_method="POST"
    )
    # DELETE
    config.add_route(
        name="delete_capability_request", pattern=f"{request_url}", request_method="DELETE"
    )


def capability_version_routes(config: Configurator):
    """
    Server routes related to capability versions

    :param config: Pyramid server config object
    """
    request_url = "capability/request/{capability_request_id}/version"
    # GET
    config.add_route(
        name="view_latest_version",
        pattern=f"{request_url}/latest",
        request_method="GET",
    )
    # POST
    config.add_route(
        name="create_capability_version", pattern=f"{request_url}/create", request_method="POST"
    )
    config.add_route(
        name="add_version_file", pattern=f"{request_url}/file/add", request_method="POST"
    )
